@@ -84,3 +84,5 @@ class Client(object):
     def sso_token(self, **kw):
         return self.call('sso_token', **kw)
 
+    def customer_invoices(self, **kw):
+        return self.call('customer_invoices', **kw)
\ No newline at end of file
